@@ -162,7 +162,7 @@ class YandexParser(object):
         import urllib
 
         match = re.search(
-            r'<a class="[^"]+?pager__item_kind_page[^"]*?"[^>]+?href="[^"]+?\?text=([^&]+)&',
+            r'<a class="[^"]+?(?:pager__item_kind_page|Pager-Item)[^"]*?"[^>]+?href="[^"]+?\?text=([^&]+)&',
             self.content
         )
         if match:
@@ -196,10 +196,17 @@ class YandexParser(object):
             r'<span class="[^"]+?pager__item_current_yes[^"]+?"[^>]*?>\s*(\d+)\s*</span>',
             self.content
         )
-        if not match:
-            return 1
+        if match:
+            return int(match.group(1))
 
-        return int(match.group(1))
+        match = re.search(
+            r'<span class="[^"]+?Pager-Item_current[^"]*?"[^>]*?>\s*(\d+)\s*</span>',
+            self.content
+        )
+        if match:
+            return int(match.group(1))
+
+        return 1
 
     def get_mobile_current_page(self):
         pages = re.findall(
@@ -637,6 +644,11 @@ class YandexParser(object):
             return True
 
         html = etree.tostring(sn, method='html', encoding='UTF-8')
+
+        # Нашлось результатов попало в блок serp-item
+        if 'serp-adv__found' in html:
+            return True
+
         # предложения магазинов
         if 'ecommerce_carousel' in html:
             return True
